@@ -41,36 +41,6 @@ import CADETMatch.loggerwriter as loggerwriter
 
 from emcee import autocorr
 
-saltIsotherms = {
-    b"STERIC_MASS_ACTION",
-    b"SELF_ASSOCIATION",
-    b"MULTISTATE_STERIC_MASS_ACTION",
-    b"SIMPLE_MULTISTATE_STERIC_MASS_ACTION",
-    b"BI_STERIC_MASS_ACTION",
-}
-
-
-from matplotlib.colors import ListedColormap
-import matplotlib.cm
-
-cmap = matplotlib.cm.winter
-
-# Get the colormap colors
-my_cmap = cmap(numpy.arange(cmap.N))
-
-# Set alpha
-my_cmap[:, -1] = 1.0
-
-# Create new colormap
-my_cmap = ListedColormap(my_cmap)
-
-cm_plot = matplotlib.cm.gist_rainbow
-
-
-def get_color(idx, max_colors, cmap):
-    return cmap(1.0 * float(idx) / max_colors)
-
-
 def main(map_function):
     cache.setup_dir(sys.argv[1])
     util.setupLog(cache.settings["resultsDirLog"], "autocorr.log")
