@@ -52,6 +52,25 @@ def bandwidth_score(bw, data, store):
     store.append([bandwidth, mean])
     return mean
 
+def get_bounds(bw_sample, bw_score):
+    idx = numpy.argmin(bw_score)
+    bw_start = bw_sample[idx]
+
+    max_idx = len(bw_sample)-1
+
+    idx_lb = idx -2
+    idx_ub = idx + 2
+
+    if idx_lb < 0:
+        idx_lb = 0
+    if idx_ub > max_idx:
+        idx_ub = max_idx
+
+    lb = bw_sample[idx_lb]
+    ub = bw_sample[idx_ub]
+
+    return bw_start, lb, ub
+
 
 def get_bandwidth(scores, cache):
     store = []
@@ -60,11 +79,9 @@ def get_bandwidth(scores, cache):
 
     bw_score = [bandwidth_score([bw,], scores, store) for bw in bw_sample]
 
-    idx = numpy.argmin(bw_score)
+    bw_start, lb, ub = get_bounds(bw_sample, bw_score)
 
-    bw_start = bw_sample[idx]
-
-    result = scipy.optimize.minimize(bandwidth_score, bw_start, args=(scores, store,), method="powell")
+    result = scipy.optimize.minimize(bandwidth_score, bw_start, args=(scores, store,), method="powell", bounds=[(lb, ub)])
     bandwidth = 10 ** result.x[0]
     multiprocessing.get_logger().info("selected bandwidth %s", bandwidth)
 
@@ -387,7 +404,10 @@ def generate_error_sequence(cache):
 
         #set delays
         block = errors_exp[:,:delay_size]
-        block = scipy.stats.uniform.ppf(block, delay_settings[0], delay_settings[1])
+        if delay_settings[0] != delay_settings[1]:
+            block = scipy.stats.uniform.ppf(block, delay_settings[0], delay_settings[1])
+        else:
+            block = numpy.ones(block.shape) * delay_settings[0]
 
         error['pump_delays'] = block
 
@@ -403,7 +423,10 @@ def generate_error_sequence(cache):
 
         block[block < min_value] = min_value
 
-        block = scipy.stats.norm.ppf(block, flow_settings[0], flow_settings[1])
+        if flow_settings[1] != 0:
+            block = scipy.stats.norm.ppf(block, flow_settings[0], flow_settings[1])
+        else:
+            block = numpy.ones(block.shape) * flow_settings[0]
 
         error['flow_rates'] = block
 
@@ -418,9 +441,12 @@ def generate_error_sequence(cache):
         #sobol sequence is [0, 1) and 0 needs to be removed and set to the same distance as the closest distance to 1
         min_value = 1 - numpy.max(block)
 
-        block[block < min_value] = min_value
+        block[block < min_value] = min_value        
 
-        block = scipy.stats.norm.ppf(block, load_settings[0], load_settings[1])
+        if load_settings[1] != 0:
+            block = scipy.stats.norm.ppf(block, load_settings[0], load_settings[1])
+        else:
+            block = numpy.ones(block.shape) * load_settings[0]
 
         error['loading_concentrations'] = block
 
@@ -476,8 +502,11 @@ def generate_synthetic_error(cache):
         errors_split = split_errors(errors_all)
         json_path = itertools.repeat(cache.json_path)
 
-        for scores, simulations, outputs, errors in cache.toolbox.map(synthetic_error_simulation, zip(json_path, errors_split)):
+        indexes = []
+
+        for idx, (scores, simulations, outputs, errors) in enumerate(cache.toolbox.map(synthetic_error_simulation, zip(json_path, errors_split))):
             if scores and simulations and outputs:
+                indexes.append(idx)
 
                 for key, value in errors["uv_store"].items():
                     uv = uv_store_all.get(key, [])
@@ -495,6 +524,12 @@ def generate_synthetic_error(cache):
                     if key not in times:
                         times[key] = sim.root.output.solution.solution_times
 
+        indexes = numpy.array(indexes)
+
+        for name,experiment in errors_all.items():
+            for error_name, error_value in experiment.items():
+                errors_all[name][error_name] = error_value[indexes,:]
+
         scores = numpy.array(scores_all)
 
         keep_idx = keep_data(scores)
