@@ -305,6 +305,48 @@ def process_sampler_auto_bounds_write(cache, mcmc_store):
     mcmc_store.root.bounds_flat_chain_transform = bounds_chain_flat_transform
 
 
+def select_bounds(chain, lb_per=15.9, ub_per=84.1, max_time=5):
+    chain_shape = chain.shape
+    flat_chain = chain.reshape(chain_shape[0] * chain_shape[1], chain_shape[2])
+    size = chain_shape[0]
+    lb, ub = numpy.percentile(flat_chain, [lb_per, ub_per], axis=0)
+
+    multiprocessing.get_logger().info("bounds selected  lb(%s) %s  ub(%s) %s", lb_per, lb, ub_per, ub)
+
+    selected = (flat_chain > lb) & (flat_chain< ub)
+    selected = numpy.all(selected, 1)
+
+    multiprocessing.get_logger().info("bounds selected %s from %s", sum(selected), len(flat_chain))
+
+    data_reduced = flat_chain[selected, :]
+
+    a = set()
+
+    #if this takes more than max_time to create enough entries take the existing ones and just augment them
+    #this should prevent getting trapped
+    start = time.time()
+
+    while len(a) < size:
+        idx = numpy.random.randint(0, data_reduced.shape[0])
+        sample = data_reduced[idx,:]
+        a.add(tuple(sample))
+
+        if time.time() > (start+max_time):
+            multiprocessing.get_logger().info("bounds time exceeded need to augment")
+            break
+    
+    select = numpy.array(list(a))
+    row = len(select)
+
+    if row < size:
+        indexes = numpy.random.choice(select.shape[0], size - row, replace=True)
+        temp = select[indexes, :]
+        rand = numpy.random.normal(1.0, diff, size=temp.shape)
+        select = numpy.concatenate([select, temp * rand])
+
+    return select
+
+
 def sampler_auto_bounds(cache, checkpoint, sampler, checkpointFile, mcmc_store):
     bounds_seq = checkpoint.get("bounds_seq", [])
 
@@ -371,26 +413,45 @@ def sampler_auto_bounds(cache, checkpoint, sampler, checkpointFile, mcmc_store):
             converged, lb, mid, ub = converged_bounds(bounds_chain[:, :, :new_parameters], 200, 1e-3)
 
             if converged:
-                # sys.exit()
                 finished = True
 
+                write_interval(-1, cache, checkpoint, checkpointFile, mcmc_store, process_sampler_auto_bounds_write)
+
                 new_min_value, center, new_max_value = rescale(
                     cache, lb, mid, ub, numpy.array(cache.MIN_VALUE), numpy.array(cache.MAX_VALUE), mcmc_store
                 )
 
+                p_burn = select_bounds(bounds_chain, lb_per=15.9, ub_per=84.1, max_time=5)
+
+                p_burn_trans = util.convert_population(p_burn, cache)
+
+                multiprocessing.get_logger().info("before bounds conversion %s", p_burn_trans)
+                multiprocessing.get_logger().info("before bounds conversion p_burn %s", p_burn)
+
                 json_path = change_bounds_json(cache, new_min_value, new_max_value, mcmc_store)
                 cache.resetTransform(json_path)
                 sampler.log_prob_fn.args[0] = json_path
                 sampler.log_prob_fn.args[1] = cache
+
+                p_burn = numpy.array([util.convert_individual_inverse(i, cache) for i in p_burn_trans])
+
+                p_burn_trans = util.convert_population(p_burn, cache)
+
+                multiprocessing.get_logger().info("after bounds conversion %s", p_burn_trans)
+                multiprocessing.get_logger().info("after bounds conversion p_burn %s", p_burn)
+
+                checkpoint["state"] = "burn_in"
+                checkpoint["p_burn"] = p_burn
+                checkpoint['ln_prob_burn'] = ln_prob
+                checkpoint['rstate_burn'] = random_state
+                checkpoint["starting_population"] = p_burn
+
+                write_checkpoint(-1, checkpoint, checkpointFile)
+
+                sampler.reset()
             else:
                 multiprocessing.get_logger().info("bounds have not yet converged in gen %s", generation)
-
-    sampler.reset()
-    checkpoint["state"] = "burn_in"
-    checkpoint["p_burn"] = p
-
-    write_interval(-1, cache, checkpoint, checkpointFile, mcmc_store, process_sampler_auto_bounds_write)
-
+                
 
 def process_interval(cache, mcmc_store, interval_chain, interval_chain_transform):
     mean = numpy.mean(interval_chain_transform, 0)
@@ -557,7 +618,9 @@ def sampler_burn(cache, checkpoint, sampler, checkpointFile, mcmc_store):
     checkpoint["state"] = "chain"
     checkpoint["p_chain"] = p
     checkpoint["ln_prob_burn"] = ln_prob
+    checkpoint["ln_prob_chain"] = ln_prob
     checkpoint["rstate_burn"] = random_state
+    checkpoint["rstate_chain"] = random_state
     checkpoint["sampler_a"] = sampler._moves[1].n
 
     write_interval(-1, cache, checkpoint, checkpointFile, mcmc_store, process_sampler_burn_write)
@@ -682,15 +745,25 @@ def sampler_run(cache, checkpoint, sampler, checkpointFile, mcmc_store):
     write_interval(-1, cache, checkpoint, checkpointFile, mcmc_store, process_sampler_run_write)
 
 
+def write_checkpoint(interval, checkpoint, checkpointFile):
+    "write the checkpoint and mcmc data at most every n seconds"
+    if "last_time" not in write_checkpoint.__dict__:
+        write_checkpoint.last_time = time.time()
+
+    if time.time() - write_checkpoint.last_time > interval:
+        with checkpointFile.open("wb") as cp_file:
+            pickle.dump(checkpoint, cp_file)
+
+        write_checkpoint.last_time = time.time()
+
 def write_interval(interval, cache, checkpoint, checkpointFile, mcmc_store, process_mcmc_store):
     "write the checkpoint and mcmc data at most every n seconds"
     if "last_time" not in write_interval.__dict__:
         write_interval.last_time = time.time()
 
-    if time.time() - write_interval.last_time > interval:
-        with checkpointFile.open("wb") as cp_file:
-            pickle.dump(checkpoint, cp_file)
+    write_checkpoint(interval, checkpoint, checkpointFile)
 
+    if time.time() - write_interval.last_time > interval:
         writeMCMC(cache, mcmc_store, process_mcmc_store)
 
         write_interval.last_time = time.time()
@@ -801,7 +874,6 @@ def run(cache, tools, creator):
     chain = chain.reshape(chain_shape[0] * chain_shape[1], chain_shape[2])
 
     if checkpoint["state"] == "complete":
-        tube_process(last=True)
         util.finish(cache)
         checkpoint["state"] = "plot_finish"
 
@@ -810,6 +882,7 @@ def run(cache, tools, creator):
 
     if checkpoint["state"] == "plot_finish":
         mle_process(last=True)
+        tube_process(last=True)
         util.graph_corner_process(cache, last=True)
     return numpy.mean(chain, 0)
 
@@ -863,7 +936,7 @@ def mle_process(last=False, interval=3600):
         mle_process.last_time = time.time()
 
 
-def get_population(base, size, diff=0.1):
+def get_population(base, size, diff=0.02):
     new_population = base
     row, col = base.shape
     multiprocessing.get_logger().info("%s", base)
@@ -873,20 +946,20 @@ def get_population(base, size, diff=0.1):
         # create new entries
         indexes = numpy.random.choice(new_population.shape[0], size - row, replace=True)
         temp = new_population[indexes, :]
-        rand = numpy.random.uniform(1.0 - diff, 1.0 + diff, size=temp.shape)
+        rand = numpy.random.normal(1.0, diff, size=temp.shape)
         new_population = numpy.concatenate([new_population, temp * rand])
     if row > size:
         # randomly select entries to keep
         indexes = numpy.random.choice(new_population.shape[0], size, replace=False)
         multiprocessing.get_logger().info("indexes: %s", indexes)
         new_population = new_population[indexes, :]
-    change = numpy.random.normal(1.0, 0.01, new_population.shape)
-    multiprocessing.get_logger().info(
-        "Initial population condition number before %s  after %s",
-        numpy.linalg.cond(new_population),
-        numpy.linalg.cond(new_population * change),
-    )
-    return new_population * change
+    #change = numpy.random.normal(1.0, 0.01, new_population.shape)
+    #multiprocessing.get_logger().info(
+    #    "Initial population condition number before %s  after %s",
+    #    numpy.linalg.cond(new_population),
+    #    numpy.linalg.cond(new_population * change),
+    #)
+    return new_population #* change
 
 
 def resetPopulation(checkpoint, cache):
@@ -916,13 +989,14 @@ def resetPopulation(checkpoint, cache):
             previousResults = numpy.hstack([previousResults, numpy.repeat(stat_MLE, row, 0)])
             multiprocessing.get_logger().info("row: %s  col:%s   shape: %s", row, col, previousResults.shape)
 
-        population = get_population(previousResults, populationSize, diff=0.1)
+        population = get_population(previousResults, populationSize, diff=0.02)
+        checkpoint["starting_population"] = population
         checkpoint["starting_population"] = [util.convert_individual_inverse(i, cache) for i in population]
         multiprocessing.get_logger().info("p_burn startup population: %s", population)
         multiprocessing.get_logger().info("p_burn startup: %s", checkpoint["starting_population"])
     else:
         checkpoint["starting_population"] = SALib.sample.sobol_sequence.sample(populationSize, parameters)
-    checkpoint["p_burn"] = checkpoint["p_bounds"] = checkpoint["starting_population"]
+    checkpoint["p_bounds"] = checkpoint["starting_population"]
 
 
 def getCheckPoint(checkpointFile, cache):
