@@ -65,7 +65,6 @@ def get_times_values(simulation, target, selected=None):
 
     return times[selected], values[selected] * target["factor"]
 
-
 def sse(data1, data2):
     return numpy.sum((data1 - data2) ** 2)
 
@@ -323,9 +322,13 @@ def runExperiment(individual, experiment, settings, target, template_sim, timeou
         featureName = feature["name"]
 
         if featureType in cache.scores:
-            scores, sse, sse_count, sim_time, sim_value, exp_value, minimize = cache.scores[featureType].run(
-                temp, target[experiment["name"]][featureName]
-            )
+            try:
+                scores, sse, sse_count, sim_time, sim_value, exp_value, minimize = cache.scores[featureType].run(
+                    temp, target[experiment["name"]][featureName]
+                )
+            except TypeError:
+                return None
+
             diff = sim_value - exp_value
 
             temp["scores"].extend(scores)
@@ -1186,42 +1189,31 @@ def graph_corner_process(cache, last=False, interval=1200):
 
     cwd = str(Path(__file__).parent)
 
+    graph_scripts = ("generate_corner_graphs.py", "generate_autocorr_graphs.py", "generate_mixing_graphs.py")
+
     if last:
-        ret = subprocess.run(
-            [sys.executable, "generate_corner_graphs.py", str(cache.json_path), str(getCoreCounts())],
-            stdin=None,
-            stdout=None,
-            stderr=None,
-            close_fds=True,
-            cwd=cwd,
-        )
+        for script in graph_scripts:
+            ret = subprocess.run(
+                [sys.executable, script, str(cache.json_path), str(getCoreCounts())],
+                stdin=None,
+                stdout=None,
+                stderr=None,
+                close_fds=True,
+                cwd=cwd,
+            )
 
-        ret = subprocess.run(
-            [sys.executable, "generate_autocorr_graphs.py", str(cache.json_path), str(getCoreCounts())],
-            stdin=None,
-            stdout=None,
-            stderr=None,
-            close_fds=True,
-            cwd=cwd,
-        )
         graph_corner_process.last_time = time.time()
     elif (time.time() - graph_corner_process.last_time) > interval:
-        subprocess.run(
-            [sys.executable, "generate_corner_graphs.py", str(cache.json_path), str(getCoreCounts())],
-            stdin=None,
-            stdout=None,
-            stderr=None,
-            close_fds=True,
-            cwd=cwd,
-        )
-        subprocess.run(
-            [sys.executable, "generate_autocorr_graphs.py", str(cache.json_path), str(getCoreCounts())],
-            stdin=None,
-            stdout=None,
-            stderr=None,
-            close_fds=True,
-            cwd=cwd,
-        )
+        for script in graph_scripts:
+            subprocess.run(
+                [sys.executable, script, str(cache.json_path), str(getCoreCounts())],
+                stdin=None,
+                stdout=None,
+                stderr=None,
+                close_fds=True,
+                cwd=cwd,
+            )
+
         graph_corner_process.last_time = time.time()
 
 
@@ -1297,7 +1289,7 @@ def getMapFunction():
     cores = getCoreCounts()
     if cores == 1:
 
-        multiprocessing.get_logger().info("CADETMatch startup: running single threaded", cores)
+        multiprocessing.get_logger().info("CADETMatch startup: running single threaded")
 
         return map
     else:
